<?php
session_start();

require_once 'db_connection.php'; // Ensure this path is correct

$response = ['success' => false, 'message' => ''];

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $productId = $_POST['product_id'] ?? '';

    if (!ctype_digit($productId)) {
        $response['message'] = 'Invalid product ID.';
        echo json_encode($response);
        exit;
    }

    try {
        $stmt = $pdo->prepare("SELECT id, name, price FROM products WHERE id = :id");
        $stmt->execute([':id' => $productId]);
        $product = $stmt->fetch();

        if (!$product) {
            $response['message'] = 'Product not found.';
        } else {
            $cart = $_SESSION['cart'] ?? [];
            if (isset($cart[$productId])) {
                $cart[$productId]['quantity'] += 1;
            } else {
                $cart[$productId] = [
                    'name' => $product['name'],
                    'price' => $product['price'],
                    'quantity' => 1,
                ];
            }
            $_SESSION['cart'] = $cart;

            $response['success'] = true;
            $response['message'] = 'Product added to cart.';
        }
    } catch (Exception $e) {
        $response['message'] = 'Error: ' . htmlspecialchars($e->getMessage());
    }
} else {
    $response['message'] = 'Invalid request method.';
}

header('Content-Type: application/json');
echo json_encode($response);
