<?php
// Include the database connection
require_once 'db_connection.php';

// Handle AJAX request
if (isset($_POST['action']) && $_POST['action'] === 'fetch_products') {
    $selectedCategory = $_POST['category'] ?? '';
    $offset = (int)($_POST['offset'] ?? 0);
    $limit = 6; // Number of products per batch

    $query = "SELECT * FROM products";
    $params = [];

    if (!empty($selectedCategory)) {
        $query .= " WHERE category = :category";
        $params[':category'] = $selectedCategory;
    }

    $query .= " LIMIT :offset, :limit";
    $stmt = $pdo->prepare($query);
    $stmt->bindParam(':offset', $offset, PDO::PARAM_INT);
    $stmt->bindParam(':limit', $limit, PDO::PARAM_INT);

    if (!empty($selectedCategory)) {
        $stmt->bindParam(':category', $selectedCategory, PDO::PARAM_STR);
    }

    $stmt->execute();
    $products = $stmt->fetchAll(PDO::FETCH_ASSOC);

    if ($products) {
        foreach ($products as $product) {
            echo '
                <div class="col-md-4 mt-4">
                <div class="card product-card position-relative">
                    <div class="image-container">
                        <img src="' . htmlspecialchars($product['image']) . '" class="card-img-top" alt="' . htmlspecialchars($product['name']) . '">
                        <div class="overlay">
                            <a href="' . htmlspecialchars($product['slug']) . '" class="btn btn-outline-light me-2">View Details</a>
                            <a href="#" class="btn btn-light"><i class="fas fa-cart-plus"></i></a>
                        </div>
                    </div>
                    <div class="card-body text-center">
                        <h5 class="card-title">' . htmlspecialchars($product['name']) . '</h5>
                        <p class="card-text">N' . number_format($product['price'], 2) . '</p>
                    </div>
                </div>
            </div>
            ';
        }
    } else {
        echo '<p class="col-12 text-center">No more products available.</p>';
    }
    exit;
}
?>





<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>E-Commerce Homepage</title>
    <!-- Bootstrap CSS -->
	<?php include "headernav.php"?>


<div class="hero6 mt-5 p-4">
    <h1 class="mt-5">SLIDE THROUGH</h1>
	
	 <div class="row mb-4">
        <div class="col-md-4 offset-md-4">
            <select id="category" class="form-select">
                <option value="">All Categories</option>
                <?php
                // Fetch categories
                $categoryQuery = "SELECT DISTINCT category FROM products";
                $categoryStmt = $pdo->prepare($categoryQuery);
                $categoryStmt->execute();
                $categories = $categoryStmt->fetchAll(PDO::FETCH_COLUMN);

                foreach ($categories as $category) {
                    echo '<option value="' . htmlspecialchars($category) . '">' . htmlspecialchars($category) . '</option>';
                }
                ?>
            </select>
        </div>
    </div>
	
	<div class="owl-carousel owl-theme">
    <?php
    try {
        // Fetch random products
        $product_sql = "SELECT * FROM products ORDER BY RAND() LIMIT 8";
        $stmt = $pdo->prepare($product_sql);
        $stmt->execute();
        $products = $stmt->fetchAll(PDO::FETCH_ASSOC);

        if (!empty($products)) {
            foreach ($products as $productx) {
                ?>
                <div class="item">
                    <div class="product-card position-relative">
                        <div class="image-container">
                            <img src="<?php echo htmlspecialchars($productx['image']); ?>" class="card-img-top" alt="<?php echo htmlspecialchars($productx['name']); ?>">
                            <div class="overlay">
                                <a href="product_detail.php?product=<?php echo htmlspecialchars($productx['slug']); ?>" class="btn btn-outline-light">View Details</a>
                                <a href="#" class="btn btn-light">
                                    <i class="fas fa-cart-plus"></i>
                                </a>
                            </div>
                        </div>
                        <h5 class="text-center"><?php echo htmlspecialchars($productx['name']); ?></h5>
                        <p class="text-center">N<?php echo number_format($productx['price'], 2); ?></p>
                    </div>
                </div>
                <?php
            }
        } else {
            echo "<p class='text-center'>No products found in the database.</p>";
        }
    } catch (PDOException $e) {
        echo "<p class='text-danger text-center'>Error fetching products: " . $e->getMessage() . "</p>";
    }
    ?>
</div>


	
			  
</div>


<!-- Product Section -->
<div class="hero4">
<div class="container bg-light ">
   
    <div class="row">
        <!-- Product Card -->
        <div class="col-12">
             
		<marquee scrollamount="25">	<h2 class=" mt-2">LET'S MAKE YOUR FASHION JOURNEY MORE EXCITING </h2></marquee>
		
    </div>
	
	   
</div>
</div>
 </div>

<div class="product_hero1">
    <div class="container">
	 <h1 class="mt-5">NEWX ARRIVALS</h1>
	 
	 
       <div class="row" id="product-container">
        <!-- Products will load here dynamically -->
    </div>
		
		
		
	  <div class="text-center mt-4">
        <button id="load-more" class="btn btn-primary" style="background-color:black;">Load More</button>
    </div>
		
	
		
		
		
    </div>
</div>




<!-- Footer -->
<footer class="footer text-center">
    <div class="container">
        <p>&copy; 2024 Your E-Commerce Site. All rights reserved.</p>
        <p>Follow us on 
            <a href="#" class="text-white">Facebook</a>, 
            <a href="#" class="text-white">Twitter</a>, 
            <a href="#" class="text-white">Instagram</a>.
        </p>
    </div>
</footer>


<!-- Bootstrap and Iconify -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://code.iconify.design/iconify-icon/1.0.7/iconify-icon.min.js"></script>



<script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.6.4/jquery.min.js"></script>
<script>
    let offset = 0; // Track product offset
    const limit = 6; // Number of products per batch

    // Fetch products via AJAX
    function fetchProducts(category = '', append = false) {
        $.ajax({
            url: 'product_1.php', // Replace with this PHP file's name
            method: 'POST',
            data: {
                action: 'fetch_products',
                category: category,
                offset: offset
            },
            success: function (response) {
                if (append) {
                    $('#product-container').append(response);
                } else {
                    $('#product-container').html(response);
                }

                // If no products are returned, hide the Load More button
                if (!response.trim()) {
                    $('#load-more').hide();
                }
            }
        });
    }

    // Initial load
    fetchProducts();

    // Category filter
    $('#category').on('change', function () {
        offset = 0; // Reset offset
        const category = $(this).val();
        $('#load-more').show(); // Show Load More button
        fetchProducts(category);
    });

    // Load More button
    $('#load-more').on('click', function () {
        offset += limit; // Increment offset
        const category = $('#category').val();
        fetchProducts(category, true);
    });
</script>
 
    <script>
        let prevScrollPos = window.pageYOffset;
        const navbar = document.querySelector('.navbar');

        window.onscroll = () => {
            const currentScrollPos = window.pageYOffset;
            if (prevScrollPos > currentScrollPos) {
                navbar.classList.remove('navbar-hidden');
            } else {
                navbar.classList.add('navbar-hidden');
            }
            prevScrollPos = currentScrollPos;
        };
    </script>



<script>
   $(document).ready(function () {
    $(".owl-carousel").owlCarousel({
        loop: true,
        margin: 10,
        nav: true,
        responsive: {
            0: { items: 1 },
            600: { items: 2 },
            1000: { items: 3 }
        }
    });
});

</script>


</body>
</html>
