<?php
session_start();
// Include the database connection file
require_once 'db_connection.php';

// Handle AJAX request for products filtering or loading
if (isset($_POST['action'])) {
    $action = $_POST['action'];
    $limit = 6; // Default limit per page
    $offset = isset($_POST['offset']) ? intval($_POST['offset']) : 0;

    if ($action === 'filter') {
        $category = $_POST['category'] ?? null;

        if ($category) {
            $sql = "SELECT * FROM products WHERE category = :category ORDER BY id DESC LIMIT :offset, :limit";
            $stmt = $pdo->prepare($sql);
            $stmt->bindParam(':category', $category, PDO::PARAM_STR);
        } else {
            $sql = "SELECT * FROM products ORDER BY id DESC LIMIT :offset, :limit";
            $stmt = $pdo->prepare($sql);
        }

        $stmt->bindValue(':offset', $offset, PDO::PARAM_INT);
        $stmt->bindValue(':limit', $limit, PDO::PARAM_INT);
        $stmt->execute();
        $products = $stmt->fetchAll();

        // Return products as HTML
        foreach ($products as $product) {
            echo '<div class="col-md-4 mt-4">
                    <div class="card product-card position-relative">
                        <div class="image-container">
                            <img src="' . htmlspecialchars($product['image']) . '" class="card-img-top" alt="' . htmlspecialchars($product['name']) . '">
                            <div class="overlay">
                                <a href="product_details.php?slug=' . htmlspecialchars($product['slug']) . '" class="btn btn-outline-light me-2">View Details</a>
                                <a href="#" class="btn btn-light"><i class="fas fa-cart-plus"></i></a>
                            </div>
                        </div>
                        <div class="card-body text-center">
                            <h5 class="card-title">' . htmlspecialchars($product['name']) . '</h5>
                            <p class="card-text">N' . number_format($product['price'], 2) . '</p>
                        </div>
                    </div>
                </div>';
        }
        exit;
    }

    if ($action === 'load_more') {
        $sql = "SELECT * FROM products ORDER BY id DESC LIMIT :offset, :limit";
        $stmt = $pdo->prepare($sql);
        $stmt->bindValue(':offset', $offset, PDO::PARAM_INT);
        $stmt->bindValue(':limit', $limit, PDO::PARAM_INT);
        $stmt->execute();
        $products = $stmt->fetchAll(PDO::FETCH_ASSOC);

        foreach ($products as $product) {
            echo '<div class="col-md-4 mt-4">
                    <div class="card product-card position-relative">
                        <div class="image-container">
                            <img src="' . htmlspecialchars($product['image']) . '" class="card-img-top" alt="' . htmlspecialchars($product['name']) . '">
                            <div class="overlay">
                                <a href="product_details.php?slug=' . htmlspecialchars($product['slug']) . '" class="btn btn-outline-light me-2">View Details</a>
                                <a href="#" data-toggle="modal" data-target="#exampleModal" class="btn btn-light"><i class="fas fa-cart-plus"></i></a>
                            </div>
                        </div>
                        <div class="card-body text-center">
                            <h5 class="card-title">' . htmlspecialchars($product['name']) . '</h5>
                            <p class="card-text"><b>N' . number_format($product['price'], 2) . '</b></p>
                        </div>
                    </div>
                </div>
				
				
				
				
		

<!-- Modal -->
<div class="modal fade" id="exampleModal" tabindex="-1" role="dialog" aria-labelledby="exampleModalLabel" aria-hidden="true">
  <div class="modal-dialog" role="document">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title" id="exampleModalLabel">Modal title</h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
      <div class="modal-body">
        ...
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
        <button type="button" class="btn btn-primary">Save changes</button>
      </div>
    </div>
  </div>
</div>
				
				
				
				
				
				
				
				
				';
        }
        exit;
    }
}

// Regular PHP logic to fetch categories
$sql = "SELECT DISTINCT category FROM products";
$categoryStmt = $pdo->prepare($sql);
$categoryStmt->execute();
$categories = $categoryStmt->fetchAll(PDO::FETCH_COLUMN);
?>



<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>E-Commerce Homepage</title>
    <!-- Bootstrap CSS -->
	<?php include "headernav.php"?>


<div class="hero6 mt-5 p-4">
    <h1 class="mt-5">SLIDEX THROUGH</h1>
	
	 <div class="row mb-4">
        <div class="col-md-4 offset-md-4">
            <select id="categoryFilter" class="form-control">
                <option value="">All Categories</option>
                <?php foreach ($categories as $category): ?>
                    <option value="<?php echo htmlspecialchars($category); ?>">
                        <?php echo htmlspecialchars($category); ?>
                    </option>
                <?php endforeach; ?>
            </select>
        </div>
    </div>
	
	
    <div class="owl-carousel owl-theme">
	
		<?php


try {
    // Query the products table using PDO
    $product_sql = "SELECT * FROM products ORDER BY RAND() LIMIT 8";
    
    // Prepare the query
    $stmt = $pdo->prepare($product_sql);
    
    // Execute the query
    $stmt->execute();
    
    // Check if any products were found
    if ($stmt->rowCount() > 0) {
        // Fetch the results
        while ($productx = $stmt->fetch(PDO::FETCH_ASSOC)) {
            ?>
            
            <div class="item">
                <div class="product-card position-relative">
                    <div class="image-container">
                        <img src="<?php echo htmlspecialchars($productx['image']); ?>" alt="<?php echo htmlspecialchars($productx['name']); ?>">
                        <div class="overlay">
                            <a href="product_details.php?slug=<?php echo htmlspecialchars($productx['slug']); ?>" class="btn btn-outline-light d-none d-md-inline">View Details</a>
                            <a href="#" class="btn btn-light d-md-none">
                                <i class="fas fa-eye d-md-none"></i>
                            </a>
                            <a href="#" class="btn btn-light">
                                <i class="fas fa-cart-plus"></i>
                            </a>
                        </div>
                    </div>
                    <h5><?php echo htmlspecialchars($productx['name']); ?></h5>
                    <p><b>N<?php echo number_format($productx['price'], 2); ?></b></p>
                </div>
            </div>
            
            <?php 
        }
    } else {
        echo "No products found.";
    }
} catch (PDOException $e) {
    // If there is an error with the query, display the error message
    echo "Error: " . $e->getMessage();
}
?>

		
			
		
        <!-- Add more items as needed -->
    </div>
	
			  
</div>


<!-- Product Section -->
<div class="hero4">
<div class="container bg-light ">
   
    <div class="row">
        <!-- Product Card -->
        <div class="col-12">
             
		<marquee scrollamount="25">	<h2 class=" mt-2">LET'S MAKE YOUR FASHION JOURNEY MORE EXCITING </h2></marquee>
		
    </div>
	
	   
</div>
</div>
 </div>

<div class="product_hero1">
    <div class="container">
	 <h1 class="mt-5">NEWX ARRIVALS</h1>
        <div class="row" id="productGrid">
            
			
			
        </div>
		
		
		
		<div class="row">
            
			<div class="col-12 text-center">
			<div class="my_btn">
            <button id="loadMore" class="btn btn-lg mt-4">VIEW MORE</button>
			</div>
        </div>
			
			
        </div>
		
	
		
		
		
    </div>
</div>




<!-- Footer -->
<footer class="footer text-center">
    <div class="container">
        <p>&copy; 2024 Your E-Commerce Site. All rights reserved.</p>
        <p>Follow us on 
            <a href="#" class="text-white">Facebook</a>, 
            <a href="#" class="text-white">Twitter</a>, 
            <a href="#" class="text-white">Instagram</a>.
        </p>
    </div>
</footer>


<!-- Bootstrap and Iconify -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://code.iconify.design/iconify-icon/1.0.7/iconify-icon.min.js"></script>



 
    <script>
        let prevScrollPos = window.pageYOffset;
        const navbar = document.querySelector('.navbar');

        window.onscroll = () => {
            const currentScrollPos = window.pageYOffset;
            if (prevScrollPos > currentScrollPos) {
                navbar.classList.remove('navbar-hidden');
            } else {
                navbar.classList.add('navbar-hidden');
            }
            prevScrollPos = currentScrollPos;
        };
    </script>



<script>
    $(document).ready(function () {
        $(".owl-carousel").owlCarousel({
            loop: true,
            margin: 10,
            nav: true,
            responsive: {
                0: { items: 2 },
                600: { items: 2 },
                1000: { items: 3 }
            }
        });
    });
</script>








<script>
$(document).ready(function () {
    let offset = 0; // Initialize offset
    const limit = 6; // Limit per page

    // Load all products initially
    loadProducts();

    // Load products based on selected category
    $('#categoryFilter').change(function () {
        offset = 0; // Reset offset when category changes
        const category = $(this).val();
        $('#productGrid').empty(); // Clear existing products
        loadProducts(category);
    });

    // Load more products
    $('#loadMore').click(function () {
        const category = $('#categoryFilter').val();
        offset += limit; // Increment offset
        loadProducts(category, offset);
    });

    // Load products via AJAX
    function loadProducts(category = '', offset = 0) {
        $.ajax({
            url: 'product_2.php', // The PHP file handling the request
            method: 'POST',
            data: { action: 'filter', category: category, offset: offset },
            success: function (data) {
                $('#productGrid').append(data); // Append new products
            }
        });
    }
});

</script>

</body>
</html>
