<?php
// Include the database connection
require_once 'db_connection.php';

// Handle AJAX request
if (isset($_POST['action']) && $_POST['action'] === 'fetch_products') {
    $selectedCategory = $_POST['category'] ?? '';
    $offset = (int)($_POST['offset'] ?? 0);
    $limit = 6; // Number of products per batch

    $query = "SELECT * FROM products";
    $params = [];

    if (!empty($selectedCategory)) {
        $query .= " WHERE category = :category";
        $params[':category'] = $selectedCategory;
    }

    $query .= " LIMIT :offset, :limit";
    $stmt = $pdo->prepare($query);
    $stmt->bindParam(':offset', $offset, PDO::PARAM_INT);
    $stmt->bindParam(':limit', $limit, PDO::PARAM_INT);

    if (!empty($selectedCategory)) {
        $stmt->bindParam(':category', $selectedCategory, PDO::PARAM_STR);
    }

    $stmt->execute();
    $products = $stmt->fetchAll(PDO::FETCH_ASSOC);

    if ($products) {
        foreach ($products as $product) {
            echo '
                <div class="col-md-4 mt-4">
                    <div class="card">
                        <img src="' . htmlspecialchars($product['image']) . '" class="card-img-top" alt="' . htmlspecialchars($product['name']) . '">
                        <div class="card-body text-center">
                            <h5 class="card-title">' . htmlspecialchars($product['name']) . '</h5>
                            <p class="card-text">N' . number_format($product['price'], 2) . '</p>
                        </div>
                    </div>
                </div>
            ';
        }
    } else {
        echo '<p class="col-12 text-center">No more products available.</p>';
    }
    exit;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Product Page</title>
  <?php include "headernav.php"?>
<div class="container mt-5">
    <h1 class="text-center">Products</h1>

    <!-- Filter Dropdown -->
    <div class="row mb-4">
        <div class="col-md-4 offset-md-4">
            <select id="category" class="form-select">
                <option value="">All Categories</option>
                <?php
                // Fetch categories
                $categoryQuery = "SELECT DISTINCT category FROM products";
                $categoryStmt = $pdo->prepare($categoryQuery);
                $categoryStmt->execute();
                $categories = $categoryStmt->fetchAll(PDO::FETCH_COLUMN);

                foreach ($categories as $category) {
                    echo '<option value="' . htmlspecialchars($category) . '">' . htmlspecialchars($category) . '</option>';
                }
                ?>
            </select>
        </div>
    </div>

    <!-- Product Grid -->
    <div class="row" id="product-container">
        <!-- Products will load here dynamically -->
    </div>

    <!-- Load More Button -->
    <div class="text-center mt-4">
        <button id="load-more" class="btn btn-primary">Load More</button>
    </div>
</div>

<!-- JS Libraries -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.6.4/jquery.min.js"></script>
<script>
    let offset = 0; // Track product offset
    const limit = 6; // Number of products per batch

    // Fetch products via AJAX
    function fetchProducts(category = '', append = false) {
        $.ajax({
            url: 'product_3.php', // Replace with this PHP file's name
            method: 'POST',
            data: {
                action: 'fetch_products',
                category: category,
                offset: offset
            },
            success: function (response) {
                if (append) {
                    $('#product-container').append(response);
                } else {
                    $('#product-container').html(response);
                }

                // If no products are returned, hide the Load More button
                if (!response.trim()) {
                    $('#load-more').hide();
                }
            }
        });
    }

    // Initial load
    fetchProducts();

    // Category filter
    $('#category').on('change', function () {
        offset = 0; // Reset offset
        const category = $(this).val();
        $('#load-more').show(); // Show Load More button
        fetchProducts(category);
    });

    // Load More button
    $('#load-more').on('click', function () {
        offset += limit; // Increment offset
        const category = $('#category').val();
        fetchProducts(category, true);
    });
</script>
</body>
</html>
