<?php
session_start();
// Include the database connection
require_once 'db_connection.php';

// Sanitize and validate the slug from the URL
$slug = $_GET['slug'] ?? '';
if (!preg_match('/^[a-zA-Z0-9-]+$/', $slug)) {
    header('HTTP/1.0 404 Not Found');
    echo "Invalid product slug.";
    exit;
}

// Fetch product details from the database
try {
    $sql = "SELECT * FROM products WHERE slug = :slug";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':slug', $slug, PDO::PARAM_STR);
    $stmt->execute();
    $product = $stmt->fetch();

    if (!$product) {
        header('HTTP/1.0 404 Not Found');
        echo "Product not found.";
        exit;
    }
} catch (PDOException $e) {
    echo "Error fetching product: " . htmlspecialchars($e->getMessage());
    exit;
}


// Handle AJAX requests
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['action'] ?? '';

    if ($action === 'add_to_cart') {
        $productId = $_POST['id'];
        $productName = $_POST['name'];
        $productPrice = $_POST['price'];
        $productImage = $_POST['image'];

        // Add product as individual item
        $_SESSION['cart'][] = [
            'id' => $productId,
            'name' => $productName,
            'price' => $productPrice,
            'image' => $productImage,
        ];

        $totalItems = count($_SESSION['cart']);
        echo json_encode(['status' => 'success', 'totalItems' => $totalItems]);
        exit;
    }

    if ($action === 'clear_cart') {
        $_SESSION['cart'] = [];
        echo json_encode(['status' => 'success']);
        exit;
    }

    if ($action === 'remove_item') {
        $index = $_POST['index'];
        if (isset($_SESSION['cart'][$index])) {
            unset($_SESSION['cart'][$index]);
            $_SESSION['cart'] = array_values($_SESSION['cart']); // Reindex
        }
        echo json_encode(['status' => 'success']);
        exit;
    }

    if ($action === 'get_cart') {
        echo json_encode($_SESSION['cart'] ?? []);
        exit;
    }
}
?>


<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>E-Commerce Homepage</title>
    <!-- Bootstrap CSS -->
	
<link rel="stylesheet" type="text/css" href="css2/style.css">
	
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
	
	
	<link rel="preconnect" href="https://fonts.googleapis.com">
<link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
<link href="https://fonts.googleapis.com/css2?family=Playfair+Display:ital,wght@0,400..900;1,400..900&display=swap" rel="stylesheet">



	<!-- Owl Carousel CSS -->
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/OwlCarousel2/2.3.4/assets/owl.carousel.min.css">
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/OwlCarousel2/2.3.4/assets/owl.theme.default.min.css">

<!-- jQuery -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.6.4/jquery.min.js"></script>

<!-- Owl Carousel JS -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/OwlCarousel2/2.3.4/owl.carousel.min.js"></script>
<link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.0/css/all.min.css" rel="stylesheet">

 <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Poppins:wght@400;500;600&display=swap">
  


     <style>
        body {
          font-family: 'Playfair Display', serif; /* Use the custom font */
        }

        .navbar {
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
            transition: top 0.3s;
        }

        .navbar-hidden {
            top: -70px; /* Adjust based on your navbar height */
        }

        .navbar-brand {
            font-weight: 600;
        }

        .nav-link {
            font-size: 1rem;
            font-weight: bold;
            color: black;
			text-transform:uppercase;
			
        }

        .nav-link:hover {
            color: #007bff;
        }

        .icon-badge {
            position: absolute;
            top: -5px;
            right: -10px;
            background: #dc3545;
            color: white;
            font-size: 0.75rem;
            padding: 2px 6px;
            border-radius: 50%;
        }
		
		
		
			@media (max-width: 767px) {
   .nav-link {
            font-size: 1rem;
            font-weight: bold;
            color: black;
			text-transform:uppercase;
			
        }
		
		#nav_not_to_show {
           display:none;
			
        }
		
		
}

		
		
		.alert-auto-hide {
            position: fixed;
            top: 20px;
            right: 20px;
            z-index: 1055;
            display: none;
        }
		
		
    </style>
	
	 
	
   
</head>
<body style="background-color: #e6ecff;">
<div class="top-bar bg-primary">
       .
    </div>
 
 
   <div class="alert alert-success alert-dismissible fade show alert-auto-hide" id="notification" role="alert">
            <span id="notificationMessage"></span>
            <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
        </div>
 
    <!-- Navbar -->
    <nav class="navbar navbar-expand-lg navbar-light bg-white fixed-top">
        <div class="container mt-4">
		
		  <!-- Toggle Button -->
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
                <span class="navbar-toggler-icon"></span>
            </button>
		
		
            <!-- Logo -->
            <a class="navbar-brand mx-auto" href="#">FUSIONXSPACE</a>
			
			 <ul class="navbar-nav me-2 d-md-none">
					<li class="nav-item">
                        <a class="nav-link" href="#" data-bs-toggle="offcanvas" data-bs-target="#offcanvasSearch">
                            <iconify-icon icon="tabler:search" class="fs-4"></iconify-icon>
                        </a>
                    </li>
						
			</ul>	

           <ul class="navbar-nav me-2 d-md-none">
					
					
					 <li class="nav-item position-relative">
                        <a class="nav-link" href="#" data-bs-toggle="offcanvas" data-bs-target="#offcanvasCart">
                            <iconify-icon icon="mdi:cart" class="fs-4"></iconify-icon>
                          <span class="icon-badge">    
           <span id="cartCount"><?= count($_SESSION['cart'] ?? []) ?></span>  </span>
                        </a>
                    </li>
				</ul>	
			

            <!-- Navbar Items -->
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav mx-auto">
                    <li class="nav-item"><a class="nav-link" href="#">Home</a></li>
                    <li class="nav-item"><a class="nav-link" href="#">Shop</a></li>
                    <li class="nav-item"><a class="nav-link" href="#">About</a></li>
                    <li class="nav-item"><a class="nav-link" href="#">Contact</a></li>
                </ul>
				
				<div class="my_btn d-md-none" >
			<center> <a href="#" data-bs-toggle="offcanvas" data-bs-target="#offcanvasProfile" class="btn btn-lg mt-4">LOGIN </a></center>
			  </div>
				
				<div id="nav_not_to_show">
				 <!-- Right Icons -->
                <ul class="navbar-nav ms-auto">
                    <!-- Search Icon -->
                    <li class="nav-item">
                        <a class="nav-link" href="#" data-bs-toggle="offcanvas" data-bs-target="#offcanvasSearch">
                            <iconify-icon icon="tabler:search" class="fs-4"></iconify-icon>
                        </a>
                    </li>
                    <!-- Cart Icon -->
                    <li class="nav-item position-relative">
                        <a class="nav-link" href="#" data-bs-toggle="offcanvas" data-bs-target="#offcanvasCart">
                            <iconify-icon icon="mdi:cart" class="fs-4"></iconify-icon>
                            <span class="icon-badge">    
           <span id="cartCount"><?= count($_SESSION['cart'] ?? []) ?></span>  </span>
                        </a>
                    </li>
                    <!-- Profile Icon -->
                    <li class="nav-item">
                        <a class="nav-link" href="#" data-bs-toggle="offcanvas" data-bs-target="#offcanvasProfile">
                            <iconify-icon icon="healthicons:person" class="fs-4"></iconify-icon>
                        </a>
                    </li>
                </ul>
				</div>
				
				
               
            </div>
        </div>
    </nav>

    <!-- Offcanvas Search -->
    <div class="offcanvas offcanvas-end" id="offcanvasSearch">
        <div class="offcanvas-header">
            <h5>Search</h5>
            <button type="button" class="btn-close" data-bs-dismiss="offcanvas"></button>
        </div>
        <div class="offcanvas-body">
            <input type="text" class="form-control" placeholder="Search for products...">
        </div>
    </div>

    <!-- Offcanvas Cart -->
    <div class="offcanvas offcanvas-end p-4" id="offcanvasCart">
        <div class="offcanvas-header">
            <h5>Your Cart</h5>
            <button type="button" class="btn-close" data-bs-dismiss="offcanvas"></button>
        </div>
       <div class="modal-body" id="cartContent">
                        <!-- Cart Content will load here -->
                    </div>
					 <button class="btn btn-danger mt-3" id="clearCartBtn">Clear Cart</button>
    </div>

    <!-- Offcanvas Profile -->
    <div class="offcanvas offcanvas-end" id="offcanvasProfile">
        <div class="offcanvas-header">
            <h5>Profile</h5>
            <button type="button" class="btn-close" data-bs-dismiss="offcanvas"></button>
        </div>
        <div class="offcanvas-body">
            <form>
                <div class="mb-3">
                    <label for="email" class="form-label">Email</label>
                    <input type="email" id="email" class="form-control" placeholder="Enter your email">
                </div>
                <div class="mb-3">
                    <label for="password" class="form-label">Password</label>
                    <input type="password" id="password" class="form-control" placeholder="Enter your password">
                </div>
                <button type="submit" class="btn btn-primary w-100">Login</button>
            </form>
        </div>
    </div>

  



<div class="hero">
<div id="carouselHero" class="carousel slide" data-bs-ride="carousel">
    <div class="carousel-inner">
        <div class="carousel-item active">
            <div class="d-block bg-light w-100" style="position: relative;">
               
               
            </div>
        </div>
       
    </div>
   
</div>

</div>





		<div class="details_hero mt-5 p-4">
    <h1 class="mt-5">SLIDEX THROUGH</h1>
		
		
					   <div class="container mt-5">
        <div class="row">
            <!-- Product Image -->
            <div class="col-md-6">
                <img src="<?php echo htmlspecialchars($product['image']); ?>" alt="<?php echo htmlspecialchars($product['name']); ?>" class="img-fluid">
            </div>
            <!-- Product Info -->
            <div class="col-md-6">
                <h1><?php echo htmlspecialchars($product['name']); ?></h1>
                <h3 class="text-primary">₦<?php echo number_format($product['price'], 2); ?></h3>
                <p><?php echo nl2br(htmlspecialchars($product['description'])); ?></p>
                <button class="btn btn-primary add-to-cart-btn" 
                        data-id="<?php echo htmlspecialchars($product['id']); ?>" 
                        data-name="<?php echo htmlspecialchars($product['name']); ?>" 
                        data-price="<?php echo htmlspecialchars($product['price']); ?>" 
                        data-image="<?php echo htmlspecialchars($product['image']); ?>">
                    Add to Cart
                </button>
            </div>
        </div>
    </div>

		
		
		</div>







<!-- Product Section -->
<div class="hero4">
<div class="container bg-light ">
   
    <div class="row">
        <!-- Product Card -->
        <div class="col-12">
             
		<marquee scrollamount="25">	<h2 class=" mt-2">LET'S MAKE YOUR FASHION JOURNEY MORE EXCITING </h2></marquee>
		
    </div>
	
	   
</div>
</div>
 </div>











<div class="hero6 mt-5 p-4">
    <h1 class="mt-5">RELATED PRODUCT</h1>
	

	
	
    <div class="owl-carousel owl-theme">
	
		<?php


try {
    // Query the products table using PDO
    $product_sql = "SELECT * FROM products ORDER BY RAND() LIMIT 8";
    
    // Prepare the query
    $stmt = $pdo->prepare($product_sql);
    
    // Execute the query
    $stmt->execute();
    
    // Check if any products were found
    if ($stmt->rowCount() > 0) {
        // Fetch the results
        while ($productx = $stmt->fetch(PDO::FETCH_ASSOC)) {
            ?>
            
            <div class="item">
                <div class="product-card position-relative">
                    <div class="image-container">
                        <img src="<?php echo htmlspecialchars($productx['image']); ?>" alt="<?php echo htmlspecialchars($productx['name']); ?>">
                        <div class="overlay">
                            <a href="product_details.php?slug=<?php echo htmlspecialchars($productx['slug']); ?>" class="btn btn-outline-light d-none d-md-inline">View Details</a>
                            <a href="#" class="btn btn-light d-md-none">
                                <i class="fas fa-eye d-md-none"></i>
                            </a>
                            <a href="#" class="btn btn-light">
                                <i class="fas fa-cart-plus"></i>
                            </a>
                        </div>
                    </div>
                    <h5><?php echo htmlspecialchars($productx['name']); ?></h5>
                    <p><b>N<?php echo number_format($productx['price'], 2); ?></b></p>
                </div>
            </div>
            
            <?php 
        }
    } else {
        echo "No products found.";
    }
} catch (PDOException $e) {
    // If there is an error with the query, display the error message
    echo "Error: " . $e->getMessage();
}
?>

		
			
		
        <!-- Add more items as needed -->
    </div>
	
			  
</div>






    <div class="container my-5">
        <h1>Product Page</h1>

        <!-- Alert Notification -->
        <div class="alert alert-success alert-dismissible fade show alert-auto-hide" id="notification" role="alert">
            <span id="notificationMessage"></span>
            <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
        </div>

        <!-- Total Cart Items -->
      

        <!-- Product Card -->
        <div class="row mt-4">
            <div class="col-md-4">
                <div class="card">
                    <img src="https://via.placeholder.com/300x200" class="card-img-top" alt="Product Image">
                    <div class="card-body">
                        <h5 class="card-title">Gold Dress</h5>
                        <p class="card-text">₦55,000.00</p>
                        <button class="btn btn-primary add-to-cart-btn" 
                            data-id="1" 
                            data-name="Gold Dress" 
                            data-price="55000" 
                            data-image="https://via.placeholder.com/300x200">
                            <span class="spinner-border spinner-border-sm d-none" role="status" aria-hidden="true"></span>
                            Add to Cart
                        </button>
                    </div>
                </div>
            </div>
        </div>

        <!-- Cart Modal -->
        <button class="btn btn-success mt-3" data-bs-toggle="modal" data-bs-target="#cartModal">View Cart</button>
        <button class="btn btn-danger mt-3" id="clearCartBtn">Clear Cart</button>

        <div class="modal fade" id="cartModal" tabindex="-1" aria-labelledby="cartModalLabel" aria-hidden="true">
            <div class="modal-dialog">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title">Your Cart</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                    </div>
                    <div class="modal-body" id="cartContent">
                        <!-- Cart Content will load here -->
                    </div>
                </div>
            </div>
        </div>
    </div>
	
	
	
	
	
	


  <!-- Bootstrap and Iconify -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://code.iconify.design/iconify-icon/1.0.7/iconify-icon.min.js"></script>
    <script>
        let prevScrollPos = window.pageYOffset;
        const navbar = document.querySelector('.navbar');

        window.onscroll = () => {
            const currentScrollPos = window.pageYOffset;
            if (prevScrollPos > currentScrollPos) {
                navbar.classList.remove('navbar-hidden');
            } else {
                navbar.classList.add('navbar-hidden');
            }
            prevScrollPos = currentScrollPos;
        };
    </script>



<script>
    $(document).ready(function () {
        $(".owl-carousel").owlCarousel({
            loop: true,
            margin: 10,
            nav: true,
            responsive: {
                0: { items: 2 },
                600: { items: 2 },
                1000: { items: 3 }
            }
        });
    });
</script>


	
	
	
	
	
	
	
	

    <script>
        // Update Cart Modal Content
        function updateCartModal() {
            $.post('', { action: 'get_cart' }, function (response) {
                const cart = JSON.parse(response);
                let content = '';

                if (cart.length === 0) {
                    content = '<p>Your cart is empty.</p>';
                } else {
                    let totalCost = 0;
                    cart.forEach((item, index) => {
                        totalCost += parseInt(item.price);
                        content += `
                            <div class="d-flex justify-content-between align-items-center mb-2">
                                <div>
                                    <img src="${item.image}" alt="${item.name}" style="width: 50px; height: 50px; margin-right: 10px;">
                                    ${item.name} - ₦${item.price}
                                </div>
                                <button class="btn btn-danger btn-sm remove-item-btn" data-index="${index}">X</button>
                            </div>`;
                    });
                    content += `<hr><h5>Total Cost: ₦${totalCost}</h5>`;
                }

                $('#cartContent').html(content);
            });
        }

        // Add to Cart Button Click
        $('.add-to-cart-btn').on('click', function () {
            const button = $(this);
            const spinner = button.find('.spinner-border');
            spinner.removeClass('d-none');
            button.prop('disabled', true);

            const productData = {
                action: 'add_to_cart',
                id: button.data('id'),
                name: button.data('name'),
                price: button.data('price'),
                image: button.data('image'),
            };

            $.post('', productData, function (response) {
                const data = JSON.parse(response);
                if (data.status === 'success') {
                    $('#cartCount').text(data.totalItems);
                    $('#notificationMessage').text('Product added to cart!');
                    $('#notification').fadeIn().delay(2000).fadeOut();
                    updateCartModal();
                }
            }).always(() => {
                spinner.addClass('d-none');
                button.prop('disabled', false);
            });
        });

        // Clear Cart Button
        $('#clearCartBtn').on('click', function () {
            $.post('', { action: 'clear_cart' }, function () {
                $('#cartCount').text(0);
                $('#notificationMessage').text('Cart cleared!');
                $('#notification').fadeIn().delay(2000).fadeOut();
                updateCartModal();
            });
        });

        // Remove Individual Item
        $(document).on('click', '.remove-item-btn', function () {
            const index = $(this).data('index');
            $.post('', { action: 'remove_item', index: index }, function () {
                $('#notificationMessage').text('Item removed from cart!');
                $('#notification').fadeIn().delay(2000).fadeOut();
                updateCartModal();
                $('#cartCount').text($('#cartContent .remove-item-btn').length - 1);
            });
        });

        // Load Modal Content Initially
        updateCartModal();
    </script>
</body>
</html>
