<?php
// Include the database connection file
require_once 'db_connection.php';

// Fetch distinct categories for the filter dropdown
$categoryQuery = "SELECT DISTINCT category FROM products";
$categoryStmt = $pdo->prepare($categoryQuery);
$categoryStmt->execute();
$categories = $categoryStmt->fetchAll(PDO::FETCH_COLUMN);

// Fetch products based on the selected category (if any)
$selectedCategory = isset($_GET['category']) && !empty($_GET['category']) ? $_GET['category'] : null;
if ($selectedCategory) {
    $sql = "SELECT * FROM products WHERE category = :category";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':category', $selectedCategory, PDO::PARAM_STR);
} else {
    $sql = "SELECT * FROM products";
    $stmt = $pdo->prepare($sql);
}

$stmt->execute();
$products = $stmt->fetchAll();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Product Listing</title>
    <link href="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .product-card {
            margin-bottom: 30px;
            border: 1px solid #ddd;
            border-radius: 8px;
            overflow: hidden;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        }
        .product-card img {
            width: 100%;
            height: 200px;
            object-fit: cover;
        }
        .product-card .card-body {
            padding: 15px;
        }
        .product-card h5 {
            font-size: 1.2rem;
            margin: 10px 0;
        }
        .product-card .price {
            color: #28a745;
            font-weight: bold;
        }
        .product-card .btn {
            width: 100%;
            background-color: #007bff;
            color: white;
        }
        .product-card .btn:hover {
            background-color: #0056b3;
        }
    </style>
</head>
<body>

<div class="container mt-5">
    <h2 class="text-center mb-4">Product Listings</h2>

    <!-- Category Filter -->
    <form method="GET" class="mb-4">
        <div class="row">
            <div class="col-md-4 offset-md-4">
                <select name="category" class="form-control" onchange="this.form.submit()">
                    <option value="">ALL CATEGORIES</option>
                    <?php foreach ($categories as $category): ?>
                        <option value="<?php echo htmlspecialchars($category); ?>" <?php echo ($selectedCategory === $category) ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($category); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
        </div>
    </form>

    <div class="row">
        <?php if ($products): ?>
            <?php foreach ($products as $product): ?>
                <div class="col-md-3">
                    <div class="card product-card">
                        <img src="<?php echo htmlspecialchars($product['image']); ?>" alt="<?php echo htmlspecialchars($product['name']); ?>">
                        <div class="card-body">
                            <h5 class="card-title"><?php echo htmlspecialchars($product['name']); ?></h5>
                            <p class="price">$<?php echo number_format($product['price'], 2); ?></p>
                            <a href="product_detail.php?slug=<?php echo htmlspecialchars($product['slug']); ?>" class="btn">View Details</a>
                        </div>
                    </div>
                </div>
            <?php endforeach; ?>
        <?php else: ?>
            <p class="col-12 text-center">No products available in this category.</p>
        <?php endif; ?>
    </div>
</div>

</body>
</html>
