<?php
session_start();

// Handle AJAX requests
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['action'] ?? '';

    if ($action === 'add_to_cart') {
        $productId = $_POST['id'];
        $productName = $_POST['name'];
        $productPrice = $_POST['price'];
        $productImage = $_POST['image'];

        // Add product as individual item
        $_SESSION['cart'][] = [
            'id' => $productId,
            'name' => $productName,
            'price' => $productPrice,
            'image' => $productImage,
        ];

        $totalItems = count($_SESSION['cart']);
        echo json_encode(['status' => 'success', 'totalItems' => $totalItems]);
        exit;
    }

    if ($action === 'clear_cart') {
        $_SESSION['cart'] = [];
        echo json_encode(['status' => 'success']);
        exit;
    }

    if ($action === 'remove_item') {
        $index = $_POST['index'];
        if (isset($_SESSION['cart'][$index])) {
            unset($_SESSION['cart'][$index]);
            $_SESSION['cart'] = array_values($_SESSION['cart']); // Reindex
        }
        echo json_encode(['status' => 'success']);
        exit;
    }

    if ($action === 'get_cart') {
        echo json_encode($_SESSION['cart'] ?? []);
        exit;
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Product Page</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.1/dist/css/bootstrap.min.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.1/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://code.jquery.com/jquery-3.6.4.min.js"></script>
    <style>
        .alert-auto-hide {
            position: fixed;
            top: 20px;
            right: 20px;
            z-index: 1055;
            display: none;
        }
    </style>
</head>
<body>
    <div class="container my-5">
        <h1>Product Page</h1>

        <!-- Alert Notification -->
        <div class="alert alert-success alert-dismissible fade show alert-auto-hide" id="notification" role="alert">
            <span id="notificationMessage"></span>
            <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
        </div>

        <!-- Total Cart Items -->
        <button class="btn btn-info">
            Cart: <span id="cartCount"><?= count($_SESSION['cart'] ?? []) ?></span> item(s)
        </button>

        <!-- Product Card -->
        <div class="row mt-4">
            <div class="col-md-4">
                <div class="card">
                    <img src="https://via.placeholder.com/300x200" class="card-img-top" alt="Product Image">
                    <div class="card-body">
                        <h5 class="card-title">Gold Dress</h5>
                        <p class="card-text">₦55,000.00</p>
                        <button class="btn btn-primary add-to-cart-btn" 
                            data-id="1" 
                            data-name="Gold Dress" 
                            data-price="55000" 
                            data-image="https://via.placeholder.com/300x200">
                            <span class="spinner-border spinner-border-sm d-none" role="status" aria-hidden="true"></span>
                            Add to Cart
                        </button>
                    </div>
                </div>
            </div>
        </div>

        <!-- Cart Modal -->
        <button class="btn btn-success mt-3" data-bs-toggle="modal" data-bs-target="#cartModal">View Cart</button>
        <button class="btn btn-danger mt-3" id="clearCartBtn">Clear Cart</button>

        <div class="modal fade" id="cartModal" tabindex="-1" aria-labelledby="cartModalLabel" aria-hidden="true">
            <div class="modal-dialog">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title">Your Cart</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                    </div>
                    <div class="modal-body" id="cartContent">
                        <!-- Cart Content will load here -->
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script>
        // Update Cart Modal Content
        function updateCartModal() {
            $.post('', { action: 'get_cart' }, function (response) {
                const cart = JSON.parse(response);
                let content = '';

                if (cart.length === 0) {
                    content = '<p>Your cart is empty.</p>';
                } else {
                    let totalCost = 0;
                    cart.forEach((item, index) => {
                        totalCost += parseInt(item.price);
                        content += `
                            <div class="d-flex justify-content-between align-items-center mb-2">
                                <div>
                                    <img src="${item.image}" alt="${item.name}" style="width: 50px; height: 50px; margin-right: 10px;">
                                    ${item.name} - ₦${item.price}
                                </div>
                                <button class="btn btn-danger btn-sm remove-item-btn" data-index="${index}">X</button>
                            </div>`;
                    });
                    content += `<hr><h5>Total Cost: ₦${totalCost}</h5>`;
                }

                $('#cartContent').html(content);
            });
        }

        // Add to Cart Button Click
        $('.add-to-cart-btn').on('click', function () {
            const button = $(this);
            const spinner = button.find('.spinner-border');
            spinner.removeClass('d-none');
            button.prop('disabled', true);

            const productData = {
                action: 'add_to_cart',
                id: button.data('id'),
                name: button.data('name'),
                price: button.data('price'),
                image: button.data('image'),
            };

            $.post('', productData, function (response) {
                const data = JSON.parse(response);
                if (data.status === 'success') {
                    $('#cartCount').text(data.totalItems);
                    $('#notificationMessage').text('Product added to cart!');
                    $('#notification').fadeIn().delay(2000).fadeOut();
                    updateCartModal();
                }
            }).always(() => {
                spinner.addClass('d-none');
                button.prop('disabled', false);
            });
        });

        // Clear Cart Button
        $('#clearCartBtn').on('click', function () {
            $.post('', { action: 'clear_cart' }, function () {
                $('#cartCount').text(0);
                $('#notificationMessage').text('Cart cleared!');
                $('#notification').fadeIn().delay(2000).fadeOut();
                updateCartModal();
            });
        });

        // Remove Individual Item
        $(document).on('click', '.remove-item-btn', function () {
            const index = $(this).data('index');
            $.post('', { action: 'remove_item', index: index }, function () {
                $('#notificationMessage').text('Item removed from cart!');
                $('#notification').fadeIn().delay(2000).fadeOut();
                updateCartModal();
                $('#cartCount').text($('#cartContent .remove-item-btn').length - 1);
            });
        });

        // Load Modal Content Initially
        updateCartModal();
    </script>
</body>
</html>
