<?php
// Include the database connection file
require_once 'db_connection.php';

// If AJAX request for products is made
if (isset($_POST['action']) && $_POST['action'] === 'filter') {
    $category = $_POST['category'] ?? null;

    if ($category) {
        $sql = "SELECT * FROM products WHERE category = :category";
        $stmt = $pdo->prepare($sql);
        $stmt->bindParam(':category', $category, PDO::PARAM_STR);
    } else {
        $sql = "SELECT * FROM products";
        $stmt = $pdo->prepare($sql);
    }

    $stmt->execute();
    $products = $stmt->fetchAll();

    // Return products as HTML
    foreach ($products as $product) {
        echo '<div class="col-md-3">
            <div class="card product-card">
                <img src="' . htmlspecialchars($product['image']) . '" alt="' . htmlspecialchars($product['name']) . '">
                <div class="card-body">
                    <h5 class="card-title">' . htmlspecialchars($product['name']) . '</h5>
                    <p class="price">$' . number_format($product['price'], 2) . '</p>
                    <button class="btn btn-info view-more" data-id="' . htmlspecialchars($product['id']) . '">View More</button>
                </div>
            </div>
        </div>';
    }
    exit;
}

// Regular PHP page
$sql = "SELECT DISTINCT category FROM products";
$categoryStmt = $pdo->prepare($sql);
$categoryStmt->execute();
$categories = $categoryStmt->fetchAll(PDO::FETCH_COLUMN);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Product Listing</title>
    <link href="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <style>
        .product-card {
            margin-bottom: 30px;
            border: 1px solid #ddd;
            border-radius: 8px;
            overflow: hidden;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        }
        .product-card img {
            width: 100%;
            height: 200px;
            object-fit: cover;
        }
        .product-card .card-body {
            padding: 15px;
        }
        .product-card h5 {
            font-size: 1.2rem;
            margin: 10px 0;
        }
        .product-card .price {
            color: #28a745;
            font-weight: bold;
        }
        .product-card .btn {
            width: 100%;
        }
    </style>
</head>
<body>

<div class="container mt-5">
    <h2 class="text-center mb-4">Product Listings</h2>

    <!-- Category Filter -->
    <div class="row mb-4">
        <div class="col-md-4 offset-md-4">
            <select id="categoryFilter" class="form-control">
                <option value="">All Categories</option>
                <?php foreach ($categories as $category): ?>
                    <option value="<?php echo htmlspecialchars($category); ?>">
                        <?php echo htmlspecialchars($category); ?>
                    </option>
                <?php endforeach; ?>
            </select>
        </div>
    </div>

    <!-- Product Grid -->
    <div class="row" id="productGrid">
        <!-- Products will be loaded dynamically here -->
    </div>
</div>

<!-- Modal for View More -->
<div class="modal fade" id="viewMoreModal" tabindex="-1" role="dialog">
    <div class="modal-dialog modal-dialog-centered" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">Product Details</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body" id="productDetails">
                <!-- Product details will be loaded dynamically here -->
            </div>
        </div>
    </div>
</div>

<script>
$(document).ready(function () {
    // Load all products initially
    loadProducts();

    // Load products based on selected category
    $('#categoryFilter').change(function () {
        const category = $(this).val();
        loadProducts(category);
    });

    // Load products via AJAX
    function loadProducts(category = '') {
        $.ajax({
            url: 'product_view_more.php', // This same file
            method: 'POST',
            data: { action: 'filter', category: category },
            success: function (data) {
                $('#productGrid').html(data);
            }
        });
    }

    // Handle View More button click
    $(document).on('click', '.view-more', function () {
        const productId = $(this).data('id');
        $.ajax({
            url: 'product_info.php',
            method: 'POST',
            data: { id: productId },
            success: function (data) {
                $('#productDetails').html(data);
                $('#viewMoreModal').modal('show');
            }
        });
    });
});
</script>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@4.5.2/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
