<?php
// Include the database connection file
require_once 'db_connection.php';

error_reporting(E_ALL);
ini_set('display_errors', 1);

if (isset($_POST['action']) && $_POST['action'] === 'load_more') {
    $offset = isset($_POST['offset']) ? (int)$_POST['offset'] : 0;
    $limit = 3;
    $selectedCategory = isset($_POST['category']) && !empty($_POST['category']) ? $_POST['category'] : null;

    if ($selectedCategory) {
        $sql = "SELECT * FROM products WHERE category = :category LIMIT :offset, :limit";
        $stmt = $pdo->prepare($sql);
        $stmt->bindValue(':category', $selectedCategory, PDO::PARAM_STR);
    } else {
        $sql = "SELECT * FROM products LIMIT :offset, :limit";
        $stmt = $pdo->prepare($sql);
    }

    $stmt->bindValue(':offset', $offset, PDO::PARAM_INT);
    $stmt->bindValue(':limit', $limit, PDO::PARAM_INT);
    $stmt->execute();
    $products = $stmt->fetchAll();

    if (empty($products)) {
        echo "No products found!";
        exit;
    }

    foreach ($products as $product) {
        echo '<div class="col-md-4">
            <div class="card product-card">
                <img src="' . htmlspecialchars($product['image']) . '" alt="' . htmlspecialchars($product['name']) . '">
                <div class="card-body">
                    <h5 class="card-title">' . htmlspecialchars($product['name']) . '</h5>
                    <p class="price">$' . number_format($product['price'], 2) . '</p>
                    <a href="product_detail.php?slug=' . htmlspecialchars($product['slug']) . '" class="btn">View Details</a>
                </div>
            </div>
        </div>';
    }
    exit;
}


// Fetch distinct categories for the filter dropdown
$categoryQuery = "SELECT DISTINCT category FROM products";
$categoryStmt = $pdo->prepare($categoryQuery);
$categoryStmt->execute();
$categories = $categoryStmt->fetchAll(PDO::FETCH_COLUMN);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Product Listing</title>
    <link href="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <style>
        .product-card {
            margin-bottom: 30px;
            border: 1px solid #ddd;
            border-radius: 8px;
            overflow: hidden;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        }
        .product-card img {
            width: 100%;
            height: 200px;
            object-fit: cover;
        }
        .product-card .card-body {
            padding: 15px;
        }
        .product-card h5 {
            font-size: 1.2rem;
            margin: 10px 0;
        }
        .product-card .price {
            color: #28a745;
            font-weight: bold;
        }
    </style>
</head>
<body>

<div class="container mt-5">
    <h2 class="text-center mb-4">Product Listings</h2>

    <!-- Category Filter -->
    <form id="filterForm" class="mb-4">
        <div class="row">
            <div class="col-md-4 offset-md-4">
                <select name="category" id="category" class="form-control">
                    <option value="">ALL CATEGORIES</option>
                    <?php foreach ($categories as $category): ?>
                        <option value="<?php echo htmlspecialchars($category); ?>">
                            <?php echo htmlspecialchars($category); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
        </div>
    </form>

    <div class="row" id="productGrid">
        <!-- Products will be dynamically loaded here -->
    </div>

    <div class="row">
        <div class="col-12 text-center">
            <button id="loadMore" class="btn btn-primary mt-4">Load More</button>
        </div>
    </div>
</div>

<script>
$(document).ready(function () {
    let offset = 0;
    const limit = 3;

    // Load initial products
    loadProducts();

    // Reload products when the category filter changes
    $('#category').change(function () {
        offset = 0;
        $('#productGrid').empty(); // Clear the current products
        $('#loadMore').show(); // Show the "Load More" button
        loadProducts();
    });

    // Load more products on button click
    $('#loadMore').click(function () {
        loadProducts();
    });

  function loadProducts() {
    const selectedCategory = $('#category').val();

    $.ajax({
        url: 'products.php', // Ensure this is the correct file path
        method: 'POST',
        data: { action: 'load_more', offset: offset, category: selectedCategory },
        success: function (data) {
            if ($.trim(data).length > 0) {
                $('#productGrid').append(data);
                offset += limit;
            } else {
                $('#loadMore').hide(); // Hide the button if no more products
            }
        },
        error: function (xhr, status, error) {
            console.error("AJAX Error:", status, error);
        }
    });
}

});
</script>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@4.5.2/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
